pub enum Decoded {
Complete {
frame: Value,
consumed: usize,
},
NeedMore(usize),
}Expand description
What decoding the head of a buffer found.
Variants
Complete
A whole frame, and how many bytes of the buffer it took.
NeedMore(usize)
At least this many more bytes are needed before trying again.