pub fn check_frame(frame: &Value) -> Result<(), FrameError>Expand description
Whether the whole frame is one the decoding rule accepts where it
arrives, the check macula runs on every frame before it is sent.
pub fn check_frame(frame: &Value) -> Result<(), FrameError>Whether the whole frame is one the decoding rule accepts where it
arrives, the check macula runs on every frame before it is sent.