pub fn check_payload(payload: &Value) -> Result<(), FrameError>Expand description
Whether payload is admissible as a frame payload. It also refuses a
payload whose own encoding is over the frame cap.
pub fn check_payload(payload: &Value) -> Result<(), FrameError>Whether payload is admissible as a frame payload. It also refuses a
payload whose own encoding is over the frame cap.