verify_relay_error

Function verify_relay_error 

pub fn verify_relay_error(
    frame: &Value,
    request: &VerifiedRequest,
    profile: Profile,
    expected_reporter: &[u8; 32],
) -> Result<VerifiedRelayError, FrameError>
Verifies a received relay error for the pending request it names, from the station the connection authenticated, expected_reporter.