pub enum ManifestError {
ChunkSizeZero,
ContentMismatch(String),
McidMismatch,
NotWhole(String),
ChunkHashes,
Malformed(String),
}Expand description
Why a manifest was refused.
Variants
ChunkSizeZero
A chunk size of zero.
ContentMismatch(String)
Content that does not match the manifest, and how.
McidMismatch
A manifest that does not describe the content id it was asked for by.
NotWhole(String)
A manifest whose chunks do not describe its content whole, and where.
ChunkHashes
A manifest whose chunk hashes do not make its root hash.
Malformed(String)
A wire form that is not a manifest, and why.