own_namespace

Function own_namespace 

pub fn own_namespace(advertisement: &Verified) -> Result<(), RecordError>
Whether a verified procedure advertisement is in its advertiser’s own namespace and admissible there: ~<node_id>/<name> where node_id is the advertiser_node verifying bound to its signer, with no authorization.