parse_public_key

Function parse_public_key 

pub fn parse_public_key(
    profile: Profile,
    carried: &[u8],
) -> Result<PublicKey, SealError>
The recipient key a key as carried holds in profile: an advertisement’s kem_key, which a caller seals to. A key of another size than the profile’s, an ML-KEM key aws-lc refuses, or a P-384 point that is not an uncompressed point on the curve is SealError::Key.