pub struct HeldObject {
pub tbs: Vec<u8>,
pub signature: Vec<u8>,
}Expand description
A signed object whose verifier already holds the signer’s key.
Fields
tbs: Vec<u8>signature: Vec<u8>Implementations
Sourceimpl HeldObject
impl HeldObject
Sourcepub fn from_value(value: &Value) -> Result<HeldObject, ObjectError>
pub fn from_value(value: &Value) -> Result<HeldObject, ObjectError>
The object in value, a map of exactly tbs and signature, each a
byte string.