pub struct SignedPublication { /* private fields */ }Expand description
A PUBLISH signed once, to be sent on several links of one node: every copy is the same publication, so a subscriber hearing it on several links delivers it once.
Implementations
Sourceimpl SignedPublication
impl SignedPublication
Sourcepub fn sign(
key: &NodeKey,
seq: &PublicationSeq,
p: Publication,
) -> Result<SignedPublication, LinkError>
pub fn sign( key: &NodeKey, seq: &PublicationSeq, p: Publication, ) -> Result<SignedPublication, LinkError>
Signs p with key at the next seq of seq.