pub enum Policy {
UcanRequired {
issuer: [u8; 32],
},
RealmMemberRequired {
key_id: [u8; 32],
can: String,
},
}Expand description
What a gated procedure requires of a request’s token.
Variants
UcanRequired
A token whose chain is rooted at the identity key of this node_id.
RealmMemberRequired
A token whose chain is rooted at the realm key of this key id,
granting a capability with this can.
Implementations