covers

Function covers 

pub fn covers(parent: &str, child: &str) -> bool
Whether a grant covers another grant or a request, by D7’s narrowing: a realm grant covers its realm, an org grant covers that org and its procedures, a procedure grant only itself. False for a with that is not one of the three MRIs, whose realm name is not canonical, or whose procedure has no org.